netapp_ontap.models.node_controller API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.node_controller`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NodeControllerSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NodeController object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `flash_cache GET`

    A list of Flash-Cache devices. Only returned when requested by name.

  `frus GET POST PATCH`

    List of FRUs on the node. Only returned when requested by name.

  `over_temperature GET`

    Specifies whether the hardware is currently operating outside of its recommended temperature range. The hardware shuts down if the temperature exceeds critical thresholds.

    Valid choices:

    - over
    - normal